using Jose;

namespace FitConnect.Encryption;

public class JoseEncryptor : IEncryptor {
    private const JweEncryption Encryption = JweEncryption.A256GCM;
    private const JweCompression Compression = JweCompression.DEF;
    private const JweAlgorithm Algorithm = JweAlgorithm.RSA_OAEP;

    private (string plainText, byte[] plainBytes, byte[] tag) Decrypt(Jwk key, string payload) {
        var result = JWE.Decrypt(payload, key);

        return (result.Plaintext, result.PlaintextBytes, result.AuthTag);
    }


    public (string plainText, byte[] plainBytes, byte[] tag) Decrypt(string key, string cipher) {
        var jwk = Jwk.FromJson(key, new Jose.JsonMapper());
        return Decrypt(jwk, cipher);
    }

    public string Encrypt(string key, string plain) {
        var jwk = Jwk.FromJson(key, new Jose.JsonMapper());
        return JWE.Encrypt(plain,
            new JweRecipient[] { new JweRecipient(Algorithm, jwk) },
            Encryption, compression: Compression);
    }

    public string Encrypt(string key, byte[] plain) {
        var jwk = Jwk.FromJson(key, new Jose.JsonMapper());
        return JWE.EncryptBytes(plain,
            new JweRecipient[] { new JweRecipient(Algorithm, jwk) },
            Encryption, compression: Compression);
    }
}
