using System.Net;
using System.Security.Cryptography.X509Certificates;
using Autofac;
using FitConnect.Services;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Logging.Abstractions;

namespace FitConnect;

public static class DiContainer {
    private static IContainer? _container;
    public static IWebProxy? WebProxy { get; set; }

    public static void DisposeContainer() {
        _container?.Dispose();
        _container = null;
    }

    public static IContainer GetContainer(FitConnectEndpoints endpoints,
        ILogger? logger = null) {
        return _container ??=
            BuildContainer(endpoints, logger);
    }

    private static IContainer
        BuildContainer(FitConnectEndpoints endpoints,
            ILogger? logger = null) {
        var builder = new ContainerBuilder();

        if (logger == null)
            logger = NullLoggerFactory.Instance.CreateLogger("FitConnect");

        builder.RegisterInstance(endpoints).As<FitConnectEndpoints>();
        builder.RegisterInstance(logger).As<ILogger>();

        builder.RegisterType<Client>();
        builder.Register(c => new OAuthService(endpoints.TokenUrl)).As<IOAuthService>();
        builder.Register(c => new SubmissionService(endpoints.SubmissionUrl[0]))
            .As<ISubmissionService>();
        builder.Register(c => new RouteService(endpoints.RoutingUrl)).As<IRouteService>();

        builder.Register(c => new Sender(
            endpoints,
            new OAuthService(endpoints.TokenUrl),
            new SubmissionService(endpoints.SubmissionUrl[0]),
            new RouteService(endpoints.RoutingUrl),
            logger)).As<Sender>();

        builder.Register(c => new Subscriber(
            endpoints,
            new OAuthService(endpoints.TokenUrl),
            new SubmissionService(endpoints.SubmissionUrl[0]),
            new RouteService(endpoints.RoutingUrl),
            logger)).As<Subscriber>();


        return builder.Build();
    }
}
