using System;
using Autofac;
using FitConnect;
using FitConnect.Models;
using Microsoft.Extensions.Logging;
using MockContainer;
using NUnit.Framework;

namespace FluentApiTest;

public class FluentSenderTests {
    private Client _client = null!;
    private IContainer _container = null!;
    private string clientId = "clientId";
    private string clientSecret = "clientSecret";
    private ILogger? logger;

    [OneTimeSetUp]
    public void OneTimeSetup() {
        _container = Container.Create();
        logger = _container.Resolve<ILogger>();
    }

    [SetUp]
    public void Setup() {
        _client = new Client(
            FitConnectEndpoints.Create(FitConnectEndpoints.EndpointType.Development),
            "", "",
            container: _container,
            logger: logger);
    }

    [Test]
    public void FluentSender_ShouldNotThrowAnError_MockingServicesWithData() {
        _client.GetSender()
            .WithDestination("destinationId")
            .WithAttachments(Array.Empty<Attachment>())
            .WithData("")
            .Submit();
    }

    [Test]
    public void FluentSender_ShouldNotThrowAnError_MockingServicesWithoutData() {
        _client.GetSender()
            .WithDestination("destinationId")
            .WithAttachments(Array.Empty<Attachment>())
            .Submit();
    }
}
